@@ -74,7 +74,7 @@ func NewTask(root, input, output string, sync bool) (Task, error) {
 		if err != nil {
 			return Task{}, err
 		}
-		t.dst = path.Join(output, path.Base(root), rel)
+		t.dst = path.Join(output, path.Base(root), filepath.ToSlash(rel))
 	}
 	return t, nil
 }
@@ -142,6 +142,7 @@ func run() int {
 	flag.IntVar(&jsMinifier.Precision, "js-precision", 0, "Number of significant digits to preserve in numbers, 0 is all")
 	flag.BoolVar(&jsMinifier.KeepVarNames, "js-keep-var-names", false, "Preserve original variable names")
 	flag.IntVar(&jsonMinifier.Precision, "json-precision", 0, "Number of significant digits to preserve in numbers, 0 is all")
+	flag.BoolVar(&jsonMinifier.KeepNumbers, "json-keep-numbers", false, "Preserve original numbers instead of minifying them")
 	flag.IntVar(&svgMinifier.Precision, "svg-precision", 0, "Number of significant digits to preserve in numbers, 0 is all")
 	flag.BoolVar(&xmlMinifier.KeepWhitespace, "xml-keep-whitespace", false, "Preserve whitespace characters but still collapse multiple into one")
 	if len(os.Args) == 1 {
