@@ -92,7 +92,7 @@ func TestHTML(t *testing.T) {
 		{` <!doctype html> <!--comment--> <html> <body><p></p></body></html> `, `<!doctype html><p>`}, // spaces before html and at the start of html are dropped
 		{`<p>x<br> y`, `<p>x<br>y`},
 		{`<p>x </b> <b> y`, `<p>x</b> <b>y`},
-		{`a <code></code> b`, `a <code></code>b`},
+		{`a <code></code> b`, `a <code></code> b`},
 		{`a <code>code</code> b`, `a <code>code</code> b`},
 		{`a <code> code </code> b`, `a <code>code</code> b`},
 		{`a <script>script</script> b`, `a <script>script</script>b`},
@@ -149,6 +149,7 @@ func TestHTML(t *testing.T) {
 		{`<script><!--<`, `<script><!--<`},
 
 		// bugs
+		{`a <span></span> b`, `a <span></span> b`},                                                               // #427
 		{`<i class="fas"></i> Text`, `<i class=fas></i> Text`},                                                   // #390
 		{`<i class="fas"> </i> Text`, `<i class=fas></i>Text`},                                                   // #390
 		{`<span translate="no">`, `<span translate=no>`},                                                         // #352
