@@ -3,12 +3,12 @@ package html
 type traits uint16
 
 const (
-	normalTag traits = 1 << iota
-	rawTag
-	nonPhrasingTag
-	objectTag
-	omitPTag // omit p end tag if it is followed by this start tag
-	keepPTag // keep p end tag if it is followed by this end tag
+	normalTag      traits = 1 << iota
+	rawTag                // raw tags need special processing for their content
+	nonPhrasingTag        // non-phrasing elements are unaffected by whitespace, remove spaces around these tags
+	objectTag             // content tags with a few exclusions, keep spaces after these open/close tags
+	omitPTag              // omit p end tag if it is followed by this start tag
+	keepPTag              // keep p end tag if it is followed by this end tag
 )
 
 const (
@@ -25,7 +25,7 @@ var tagMap = map[Hash]traits{
 	Area:       normalTag,
 	Article:    nonPhrasingTag | omitPTag,
 	Aside:      nonPhrasingTag | omitPTag,
-	Audio:      objectTag | keepPTag,
+	Audio:      keepPTag,
 	B:          normalTag,
 	Base:       normalTag,
 	Bb:         normalTag,
@@ -95,7 +95,7 @@ var tagMap = map[Hash]traits{
 	Output:     nonPhrasingTag,
 	P:          nonPhrasingTag | omitPTag,
 	Param:      normalTag,
-	Picture:    objectTag,
+	Picture:    normalTag,
 	Pre:        nonPhrasingTag | omitPTag,
 	Progress:   objectTag,
 	Q:          objectTag,
@@ -226,7 +226,7 @@ var attrMap = map[Hash]traits{
 	Tabindex:        trimAttr,
 	Target:          caselessAttr,
 	Text:            caselessAttr,
-	Translate:       booleanAttr,
+	Translate:       caselessAttr,
 	Truespeed:       booleanAttr,
 	Type:            caselessAttr,
 	Typemustmatch:   booleanAttr,
@@ -244,7 +244,7 @@ var jsMimetypes = map[string]bool{
 	"application/javascript": true,
 }
 
-// Entities are all named character entities.
+// EntitiesMap are all named character entities.
 var EntitiesMap = map[string][]byte{
 	"AElig":                           []byte("&#198;"),
 	"AMP":                             []byte("&"),
@@ -1340,6 +1340,7 @@ var EntitiesMap = map[string][]byte{
 	"zigrarr":             []byte("&#8669;"),
 }
 
+// TextRevEntitiesMap is a map of escapes.
 var TextRevEntitiesMap = map[byte][]byte{
 	'<': []byte("&lt;"),
 }
